summaryrefslogtreecommitdiffstats
path: root/kdirstat/ktreemaptile.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:04 -0600
commita327682a10bf292b58ea4f2b5d47509f3150a5c6 (patch)
tree0d195090492524b7a80f499453d2d29f024a1ff6 /kdirstat/ktreemaptile.cpp
parentc71ade2e373d85acf1357494b42202293dd771d2 (diff)
downloadkdirstat-a327682a10bf292b58ea4f2b5d47509f3150a5c6.tar.gz
kdirstat-a327682a10bf292b58ea4f2b5d47509f3150a5c6.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c71ade2e373d85acf1357494b42202293dd771d2.
Diffstat (limited to 'kdirstat/ktreemaptile.cpp')
-rw-r--r--kdirstat/ktreemaptile.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdirstat/ktreemaptile.cpp b/kdirstat/ktreemaptile.cpp
index 6efed77..5826eb0 100644
--- a/kdirstat/ktreemaptile.cpp
+++ b/kdirstat/ktreemaptile.cpp
@@ -79,7 +79,7 @@ KTreemapTile::init()
// Set up height (z coordinate) - one level higher than the parent so this
// will be closer to the foreground.
//
// Note that this must happen before any children are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );
@@ -184,12 +184,12 @@ KTreemapTile::createSquarifiedChildren( const TQRect & rect )
#endif
KFileInfoSortedBySizeIterator it( _orig, minSize, KDotEntryAsSubDir );
- TQRect childrenRect = rect;
+ TQRect tqchildrenRect = rect;
while ( *it )
{
- KFileInfoList row = squarify( childrenRect, scale, it );
- childrenRect = layoutRow( childrenRect, scale, row );
+ KFileInfoList row = squarify( tqchildrenRect, scale, it );
+ tqchildrenRect = layoutRow( tqchildrenRect, scale, row );
}
}
@@ -287,7 +287,7 @@ KTreemapTile::layoutRow( const TQRect & rect,
return rect;
- // Set up a cushion surface for this layout row:
+ // Set up a cushion surface for this tqlayout row:
// Add another ridge perpendicular to the row's direction
// that optically groups this row's tiles together.
@@ -79,7 +79,7 @@ KTreemapTile::init()
// will be closer to the foreground.
//
- // Note that this must happen before any children are created.
+ // Note that this must happen before any tqchildren are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );